==> haskell-filemanip-0.3.6.3-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-filemanip.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: filemanip
version: 0.3.6.3
id: filemanip-0.3.6.3-9giY7J5s1R0FqQX715Wz4K
key: filemanip-0.3.6.3-9giY7J5s1R0FqQX715Wz4K
license: BSD3
maintainer: Bryan O'\''Sullivan
homepage: https://github.com/bos/filemanip
synopsis: Expressive file and directory manipulation for Haskell.
description:
    A Haskell library for working with files and directories.
    Includes code for pattern matching, finding files,
    modifying file contents, and more.
category: System
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    System.FilePath.Find System.FilePath.Glob
    System.FilePath.GlobPattern System.FilePath.Manip
abi: 0c34dd16df81fa8ce4482c86f23ad0f2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/filemanip-0.3.6.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/filemanip-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/filemanip-0.3.6.3
hs-libraries: HSfilemanip-0.3.6.3-9giY7J5s1R0FqQX715Wz4K
depends:
    base-4.10.1.0 bytestring-0.10.8.2 directory-1.3.0.2
    filepath-1.4.1.2 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
haddock-interfaces: /usr/share/doc/haskell-filemanip/html/filemanip.haddock
haddock-html: /usr/share/doc/haskell-filemanip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filemanip-0.3.6.3-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-filemanip.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: filemanip
version: 0.3.6.3
id: filemanip-0.3.6.3-KxvhxhnKj2LtPlWwckuah
key: filemanip-0.3.6.3-KxvhxhnKj2LtPlWwckuah
license: BSD3
maintainer: Bryan O'\''Sullivan
homepage: https://github.com/bos/filemanip
synopsis: Expressive file and directory manipulation for Haskell.
description:
    A Haskell library for working with files and directories.
    Includes code for pattern matching, finding files,
    modifying file contents, and more.
category: System
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    System.FilePath.Find System.FilePath.Glob
    System.FilePath.GlobPattern System.FilePath.Manip
abi: 2b61fa901596dceac0e3c435a820c69c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/filemanip-0.3.6.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/filemanip-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/filemanip-0.3.6.3
hs-libraries: HSfilemanip-0.3.6.3-KxvhxhnKj2LtPlWwckuah
depends:
    base-4.10.1.0 bytestring-0.10.8.2 directory-1.3.0.2
    filepath-1.4.1.2 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
haddock-interfaces: /usr/share/doc/haskell-filemanip/html/filemanip.haddock
haddock-html: /usr/share/doc/haskell-filemanip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
